<?xml version="1.0" encoding="UTF-8"?>
<!-- @version-tag-EPD@ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:process="http://lca.jrc.it/ILCD/Process"
                xmlns:common="http://lca.jrc.it/ILCD/Common"
                xmlns:epd="http://www.pe-international.com/EPD/2007"
                version="1.0"
                exclude-result-prefixes="xsl xs process common">

    <xsl:import href="process2html.xsl"/>

    <!-- use this parameter to define which fields are to be displayed. Allowed values: mandatory, recommended, all -->

    <xsl:param name="showFieldsMode">all</xsl:param>

    <!-- default language for which language codes are not displayed -->

    <xsl:param name="defaultLanguage" select="'de'"/>
    
    <!-- alternative language to fall back to if no data is available for the default language specified above -->

    <xsl:param name="alternativeLanguage" select="'en'"/>
    
     <!-- EPD customizations -->


    <xsl:param name="roundReferenceFlowAmount" select="'true'"/>

    <!-- captions -->

    <xsl:variable name="caption.contents">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text> Inhalt: </xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text> Contents: </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:variable name="caption.environmentalIndicators">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Umweltindikatoren</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Environmental indicators</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:variable name="caption.indicators">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Indikatoren</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Indicators</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:variable name="caption.indicator">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Indikator</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Indicator</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:variable name="caption.LCIIndicators">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Indikatoren der Sachbilanz</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>LCI indicators </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="caption.LCIAIndicators">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Indikatoren der Wirkbilanz</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>LCIA indicators </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="caption.inputs">
        <xsl:text>Inputs</xsl:text>
    </xsl:variable>
    
    <xsl:variable name="caption.outputs">
        <xsl:text>Outputs</xsl:text>
    </xsl:variable>
    
    <xsl:variable name="caption.direction">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Richtung</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Direction</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:variable name="caption.value">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Wert</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Value</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="caption.unit">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Einheit</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Unit</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="caption.amount">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Menge</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Amount</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="caption.fractions">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Anteile</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Fractions</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="caption.referenceFlow">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Referenzfluss (Flussdatensatz)</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Reference flow (flow data set)</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="caption.yes">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Ja</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Yes</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:variable name="caption.no">
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:text>Nein</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>No</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>




    <!-- hide exchanges section -->

    <xsl:template match="process:exchanges" priority="40"/>

    <!-- adjust type of dataset -->

    <xsl:template match="process:modellingAndValidation/process:LCIMethodAndAllocation/process:typeOfDataSet/text()"
                 priority="100">
        <xsl:value-of select="'EPD-XML-Format'"/>
    </xsl:template>

    <!-- build table of contents -->

    <xsl:template name="makeToc">
        <tr>
            <td class="toc" colspan="2">
                <xsl:value-of select="$caption.contents"/>
                <xsl:for-each select="/*/*[local-name()!='exchanges' and local-name()!='administrativeInformation']">
                    <xsl:choose>
                        <xsl:when test="position()!=last()">
                            <xsl:variable name="fieldShortDesc">
                                <xsl:call-template name="getFieldShortDesc">
                                    <xsl:with-param name="fieldName" select="local-name()"/>
                                </xsl:call-template>
                            </xsl:variable>
                            <a href="#{local-name()}">
                                <xsl:value-of select="$fieldShortDesc"/>
                            </a>
                            <xsl:text>  -  </xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <a href="#{$caption.environmentalIndicators}">
                                <xsl:value-of select="$caption.environmentalIndicators"/>
                            </a>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:for-each>
            </td>
        </tr>
    </xsl:template>


    <!-- subsection datasetInformation -->

    <xsl:template match="/*/*/process:dataSetInformation" priority="10">
        <xsl:variable name="fieldShortDesc">
            <xsl:call-template name="getFieldShortDesc">
                <xsl:with-param name="fieldName" select="local-name()"/>
            </xsl:call-template>
        </xsl:variable>
        <tr>
            <td class="subsection" colspan="2" style="padding-left: 20px;">
                <xsl:value-of select="$fieldShortDesc"/>
            </td>
        </tr>
        <xsl:apply-templates select="../process:geography/process:locationOfOperationSupplyOrProduction"
                           mode="override"/>
        <xsl:apply-templates select="../process:time/common:referenceYear" mode="override"/>
        <xsl:apply-templates select="process:name"/>
        <xsl:apply-templates select="process:identifierOfSubDataSet"/>
        <xsl:apply-templates select="../process:technology/process:technologicalApplicability"
                           mode="override"/>
        <xsl:apply-templates select="process:functionalUnitFlowProperties"/>
        <xsl:apply-templates select="common:synonyms"/>
        <xsl:apply-templates select="/process:processDataSet/process:exchanges/process:exchange/process:referenceToFlowDataSet"/>

        <xsl:call-template name="masterTemplate">
            <xsl:with-param name="currentName" select="local-name()"/>
            <xsl:with-param name="applyTemplates" select="false()"/>
            <xsl:with-param name="omitIfEmpty" select="false()"/>
            <xsl:with-param name="disableDescendantCount" select="false()"/>
            <xsl:with-param name="copy" select="true()"/>
            <xsl:with-param name="fieldShortDesc" select="$caption.amount"/>
            <xsl:with-param name="paddingleft" select="30"/>
            <xsl:with-param name="data">

                <xsl:variable name="amount">
                    <xsl:call-template name="styleNumber">
                        <xsl:with-param name="number"
                                  select="/process:processDataSet/common:other/epd:EPD/epd:referenceFlowAmount/text()"/>
                        <xsl:with-param name="round" select="$roundReferenceFlowAmount"/>
                        <xsl:with-param name="precision"
                                  select="string-length(substring-before(/process:processDataSet/common:other/epd:EPD/epd:referenceFlowAmount/text(), '.'))+1"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:choose>
                    <xsl:when test="$defaultLanguage='de'">
                        <xsl:value-of select="translate($amount, '.', ',')"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$amount"/>
                    </xsl:otherwise>
                </xsl:choose>
                
                <!-- show unit -->

                <xsl:text> </xsl:text>
                <xsl:call-template name="getUnitGroupAndFlowProperty">
                    <xsl:with-param name="flowDatasetURI"
                               select="/*/process:exchanges/process:exchange/process:referenceToFlowDataSet/@uri"/>
                </xsl:call-template>
            </xsl:with-param>
        </xsl:call-template>
        <xsl:apply-templates select="../../process:modellingAndValidation/process:dataSourcesTreatmentAndRepresentativeness/process:useAdviceForDataSet"
                           mode="overrideHighlight"/>
        <xsl:apply-templates select="process:classificationInformation"/>

        <tr>
            <td/>
            <td class="data">
                <table class="data">
                    <tr>
                        <td valign="bottom">
                            <xsl:call-template name="rowMasterTemplate">
                                <xsl:with-param name="omitIfEmpty" select="false()"/>
                                <xsl:with-param name="displayFieldName" select="false()"/>
                                <xsl:with-param name="copy" select="true()"/>
                                <xsl:with-param name="data">
                                    <xsl:apply-templates select="/process:processDataSet/process:administrativeInformation/process:publicationAndOwnership/common:copyright"
                                                mode="override"/>
                                </xsl:with-param>
                            </xsl:call-template>
                        </td>
                        <td valign="bottom">
                            <xsl:call-template name="rowMasterTemplate">
                                <xsl:with-param name="omitIfEmpty" select="false()"/>
                                <xsl:with-param name="displayFieldName" select="false()"/>
                                <xsl:with-param name="copy" select="true()"/>
                                <xsl:with-param name="data">
                                    <xsl:apply-templates select="/process:processDataSet/process:administrativeInformation/process:publicationAndOwnership/common:referenceToOwnershipOfDataSet"/>
                                </xsl:with-param>
                            </xsl:call-template>
                        </td>
                        <td valign="bottom">
                            <xsl:call-template name="rowMasterTemplate">
                                <xsl:with-param name="omitIfEmpty" select="false()"/>
                                <xsl:with-param name="displayFieldName" select="false()"/>
                                <xsl:with-param name="copy" select="true()"/>
                                <xsl:with-param name="data">
                                    <xsl:apply-templates select="process:referenceToExternalDocumentation"/>
                                </xsl:with-param>
                            </xsl:call-template>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <xsl:apply-templates select="common:generalComment"/>
    </xsl:template>



    <xsl:template match="common:copyright" mode="override" priority="20">
        <xsl:call-template name="masterTemplate">
            <xsl:with-param name="applyTemplates" select="false()"/>
            <xsl:with-param name="omitIfEmpty" select="true()"/>
            <xsl:with-param name="copy" select="true()"/>
            <xsl:with-param name="data">
                <xsl:choose>
                    <xsl:when test=".='true' or .='1'">
                        <xsl:value-of select="$caption.yes"/>
                    </xsl:when>
                    <xsl:when test=".='false' or .='0'">
                        <xsl:value-of select="$caption.no"/>
                    </xsl:when>
                </xsl:choose>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:template>


    <xsl:template match="process:exchanges">
        <!-- holds the elements to display in the order they are supposed to appear in -->

        <xsl:variable name="exchangeElements"
                    select="'referenceToVariable,location,referenceToFlowDataSet,resultingAmount,meanAmount,minimumAmount,maximumAmount,uncertaintyDistributionType,relativeStandardDeviation95In,allocations,functionType,dataSourceType,dataDerivationTypeStatus'"/>

        <!-- holds a list of the above elements that are non-empty -->

        <xsl:variable name="nonEmptyExchangeElements">
            <xsl:call-template name="getNonEmptyExchangeElements">
                <xsl:with-param name="list" select="$exchangeElements"/>
            </xsl:call-template>
        </xsl:variable>

        <tr>
            <td class="section" colspan="2" style="padding-left: 10px;">
                <a name="{name()}">
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="$caption.indicators"/>
                </a>
            </td>
        </tr>

        <xsl:call-template name="processExchangesSubSection">
            <xsl:with-param name="direction" select="'Input'"/>
            <xsl:with-param name="nonEmptyExchangeElements" select="$nonEmptyExchangeElements"/>
        </xsl:call-template>
        <xsl:call-template name="processExchangesSubSection">
            <xsl:with-param name="direction" select="'Output'"/>
            <xsl:with-param name="nonEmptyExchangeElements" select="$nonEmptyExchangeElements"/>
        </xsl:call-template>

    </xsl:template>




    <xsl:template match="/*/common:other">
        <tr>
            <td class="section" colspan="2" style="padding-left: 10px;">
            <a name="{$caption.environmentalIndicators}"/>
            <xsl:value-of select="$caption.environmentalIndicators"/>
         </td>
        </tr>
        <tr>
            <td class="subsection" colspan="2" style="padding-left: 20px;">
            <xsl:value-of select="$caption.LCIIndicators"/>
         </td>
        </tr>
        <tr>
            <td colspan="2">
                <table width="100%">
                    <xsl:call-template name="tableHeader">
                        <xsl:with-param name="richtung" select="true()"/>
                        <xsl:with-param name="anteile" select="true()"/>
                    </xsl:call-template>
                    <tr>
                        <td class="subsection" colspan="6" style="padding-left: 40px;">
                     <xsl:value-of select="$caption.inputs"/>
                  </td>
                    </tr>
                    <xsl:for-each select="epd:EPD/epd:LCIIndicators/epd:indicator[epd:exchangeDirection[text()='Input']]">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                    <tr>
                        <td class="subsection" colspan="6" style="padding-left: 40px;">
                     <xsl:value-of select="$caption.outputs"/>
                  </td>
                    </tr>
                    <xsl:for-each select="epd:EPD/epd:LCIIndicators/epd:indicator[epd:exchangeDirection[text()='Output']]">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                </table>
            </td>
        </tr>
        <tr>
            <td class="subsection" colspan="2" style="padding-left: 20px;">
            <xsl:value-of select="$caption.LCIAIndicators"/>
         </td>
        </tr>
        <tr>
            <td colspan="2">
                <table width="100%">
                    <xsl:call-template name="tableHeader"/>
                    <xsl:apply-templates select="epd:EPD/epd:LCIAIndicators/epd:indicator"/>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template name="tableHeader">
        <xsl:param name="richtung" select="false()"/>
        <xsl:param name="anteile" select="false()"/>
        <tr class="table_header">
            <th width="5%"/>
            <th width="50%">
            <xsl:value-of select="$caption.indicator"/>
         </th>
            <th width="5%">
                <xsl:if test="$richtung='true'">
               <xsl:value-of select="$caption.direction"/>
            </xsl:if>
            </th>
            <th width="10%">
            <xsl:value-of select="$caption.value"/>
         </th>
            <th width="17%">
            <xsl:value-of select="$caption.unit"/>
         </th>
            <th width="5%">
                <xsl:if test="$anteile='true'">
               <xsl:value-of select="$caption.fractions"/>
            </xsl:if>
            </th>
        </tr>
    </xsl:template>

    <xsl:template match="epd:indicator">
        <tr class="exchanges_data">
            <td/>
            <td>
                <xsl:value-of select="epd:referenceToLCIAMethodDataSet/common:shortDescription"/>
            </td>
            <td>
                <xsl:value-of select="epd:exchangeDirection"/>
            </td>
            <td align="right">
                <xsl:call-template name="styleNumber">
                    <xsl:with-param name="number" select="epd:totalAmount"/>
                    <xsl:with-param name="round" select="true()"/>
                </xsl:call-template>
            </td>
            <td>
                <xsl:variable name="unit">
                    <xsl:call-template name="getUnitGroupReferenceUnitName">
                        <xsl:with-param name="unitGroupDataset"
                                  select="document(epd:referenceToUnitGroupDataSet/@uri, /)"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:choose>
                    <xsl:when test="$unit!=''">
                        <xsl:value-of select="$unit"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="epd:referenceToUnitGroupDataSet/common:shortDescription"/>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td>
                <xsl:if test="epd:parts">
                    <xsl:variable name="sum">
                        <xsl:call-template name="styleNumber">
                            <xsl:with-param name="number" select="round(sum(epd:parts/epd:part/@fraction)*10) div 10"/>
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:choose>
                        <xsl:when test="not($sum=100)">
                            <p style="color: red">
                                <xsl:call-template name="styleNumber">
                                    <xsl:with-param name="number" select="$sum"/>
                                </xsl:call-template>
                                <xsl:text> %</xsl:text>
                            </p>
                        </xsl:when>
                    </xsl:choose>
                </xsl:if>
            </td>
        </tr>
        <xsl:apply-templates select="epd:parts/epd:part"/>

    </xsl:template>

    <xsl:template match="epd:parts/epd:part">
        <tr class="exchanges_data">
            <td width="40px"/>
            <td style="padding-left: 30px"> - <xsl:value-of select="@name"/>
            </td>
            <td/>
            <td/>
            <td/>
            <td>
                <xsl:call-template name="styleNumber">
                    <xsl:with-param name="number" select="round(@fraction)"/>
                </xsl:call-template> % </td>
        </tr>
    </xsl:template>


    <xsl:template match="process:referenceToFlowDataSet">
        <xsl:call-template name="masterTemplate">
            <xsl:with-param name="currentName" select="local-name()"/>
            <xsl:with-param name="applyTemplates" select="false()"/>
            <xsl:with-param name="omitIfEmpty" select="false()"/>
            <xsl:with-param name="disableDescendantCount" select="false()"/>
            <xsl:with-param name="copy" select="true()"/>
            <xsl:with-param name="fieldShortDesc" select="$caption.referenceFlow"/>
            <xsl:with-param name="data">
                <xsl:call-template name="renderReference"/>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:template>


    <xsl:template match="/process:processDataSet/process:processInformation/process:geography"/>

    <xsl:template match="/process:processDataSet/process:processInformation/process:time[common:referenceYear and count(child::*[local-name()!='referenceYear'])=0]"
                 priority="100"> </xsl:template>


    <xsl:template name="styleNumber">
        <xsl:param name="number"/>
        <xsl:param name="round" select="false()"/>
        <xsl:param name="precision" select="3"/>
        <xsl:variable name="rounded">
            <xsl:choose>
                <xsl:when test="$round='true'">
                    <xsl:call-template name="formatNumber">
                        <xsl:with-param name="number" select="$number"/>
                        <xsl:with-param name="precision" select="$precision"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$number"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="$defaultLanguage='de'">
                <xsl:value-of select="translate($rounded, '.', ',')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$rounded"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="formatNumber">
        <xsl:param name="number"/>
        <xsl:param name="precision" select="3"/>
        <xsl:variable name="negative">
            <xsl:choose>
                <xsl:when test="number($number) &lt; 0">
                    <xsl:value-of select="true()"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="false()"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <!-- scientific notation: do nothing -->

            <xsl:when test="contains($number, 'E')">
                <xsl:variable name="base" select="substring-before($number, 'E')"/>
                <xsl:variable name="exponent" select="substring-after($number, 'E')"/>
                <xsl:variable name="formatted">
                    <xsl:call-template name="formatNumber">
                        <xsl:with-param name="number" select="$base"/>
                        <xsl:with-param name="precision" select="$precision"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:value-of select="concat($formatted, 'E', $exponent)"/>
            </xsl:when>
            <!-- all other cases -->

            <xsl:otherwise>
                <xsl:variable name="base">
                    <xsl:choose>
                        <xsl:when test="contains($number, '.')">
                            <xsl:value-of select="substring-before($number, '.')"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$number"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:variable name="basedigits">
                    <xsl:choose>
                        <xsl:when test="number($base) = 0">
                            <xsl:value-of select="0"/>
                        </xsl:when>
                        <xsl:when test="number($base) &lt; 0">
                            <xsl:value-of select="string-length($base) - 1"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="string-length($base)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:variable name="basefactor" select="$precision - $basedigits"/>
                <xsl:variable name="zerosAfterComma">
                    <xsl:choose>
                        <xsl:when test="$basefactor &gt; 0">
                            <xsl:call-template name="countZerosAfterDecimalSeparator">
                                <xsl:with-param name="number" select="$number"/>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="0"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>

                <xsl:variable name="formatString">
                    <xsl:text>0</xsl:text>
                    <xsl:if test="$basefactor &gt; 0">
                        <xsl:text>.</xsl:text>
                    </xsl:if>
                    <xsl:call-template name="padding">
                        <xsl:with-param name="chars" select="'#'"/>
                        <xsl:with-param name="length" select="$basefactor + $zerosAfterComma"/>
                    </xsl:call-template>
                </xsl:variable>

                <xsl:value-of select="format-number($number, $formatString)"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <xsl:template name="power">
        <xsl:param name="base"/>
        <xsl:param name="exponent"/>
        <xsl:param name="result" select="1"/>
        <xsl:choose>
            <xsl:when test="$exponent &lt; 0 or contains(string($exponent), '.')">
                <xsl:text>NaN</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="_power">
                    <xsl:with-param name="base" select="$base"/>
                    <xsl:with-param name="exponent" select="$exponent"/>
                    <xsl:with-param name="result" select="1"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="_power">
        <xsl:param name="base"/>
        <xsl:param name="exponent"/>
        <xsl:param name="result" select="1"/>
        <xsl:choose>
            <xsl:when test="$exponent = 0">
                <xsl:value-of select="$result"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="_power">
                    <xsl:with-param name="base" select="$base"/>
                    <xsl:with-param name="exponent" select="$exponent - 1"/>
                    <xsl:with-param name="result" select="$result * $base"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <xsl:template name="countZerosAfterDecimalSeparator">
        <xsl:param name="number"/>
        <xsl:param name="result" select="0"/>
        <xsl:choose>
            <xsl:when test="starts-with(substring-after($number, '.'), '0')">
                <xsl:variable name="_result">
                    <xsl:call-template name="countZerosAfterDecimalSeparator">
                        <xsl:with-param name="number" select="$number * 10"/>
                        <xsl:with-param name="result" select="$result + 1"/>
                    </xsl:call-template>
                </xsl:variable>
                <xsl:value-of select="$_result"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$result"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- end EPD customizations -->


</xsl:stylesheet>